@@ -1,6 +1,6 @@
 var fir__filter_8h =
 [
-    [ "gr::filter::kernel::fir_filter< IN_T, OUT_T, TAP_T >", "classgr_1_1filter_1_1kernel_1_1fir__filter.html", "classgr_1_1filter_1_1kernel_1_1fir__filter" ],
+    [ "gr::filter::kernel::fir_filter&lt; IN_T, OUT_T, TAP_T &gt;", "classgr_1_1filter_1_1kernel_1_1fir__filter.html", "classgr_1_1filter_1_1kernel_1_1fir__filter" ],
     [ "gr::filter::kernel::fir_filter_ccc", "namespacegr_1_1filter_1_1kernel.html#a27b343419254f9698b6243950bd1285c", null ],
     [ "gr::filter::kernel::fir_filter_ccf", "namespacegr_1_1filter_1_1kernel.html#a1262ff76f6ac8db1310e3eff81cb51c1", null ],
     [ "gr::filter::kernel::fir_filter_fcc", "namespacegr_1_1filter_1_1kernel.html#a586eaffdd2e520f032d4d5eaf6764a9b", null ],
