@@ -1,6 +1,6 @@
 var fmcomms2__sink_8h =
 [
-    [ "gr::iio::fmcomms2_sink< T >", "classgr_1_1iio_1_1fmcomms2__sink.html", "classgr_1_1iio_1_1fmcomms2__sink" ],
+    [ "gr::iio::fmcomms2_sink&lt; T &gt;", "classgr_1_1iio_1_1fmcomms2__sink.html", "classgr_1_1iio_1_1fmcomms2__sink" ],
     [ "gr::iio::fmcomms2_sink_fc32", "namespacegr_1_1iio.html#a0878c73ff9527b1936f1bdea1d555e2d", null ],
     [ "gr::iio::fmcomms2_sink_s", "namespacegr_1_1iio.html#ad953dd4ce48f63000b6948c78bfb046d", null ],
     [ "gr::iio::fmcomms2_sink_sc16", "namespacegr_1_1iio.html#af5b0a70ce15d32d03a383033a8b01e4b", null ]
