@@ -1,6 +1,6 @@
 var group__fourier__analysis__blk =
 [
-    [ "gr::fft::fft_v< T, forward >", "classgr_1_1fft_1_1fft__v.html", [
+    [ "gr::fft::fft_v&lt; T, forward &gt;", "classgr_1_1fft_1_1fft__v.html", [
       [ "sptr", "classgr_1_1fft_1_1fft__v.html#a645dd1069dc5f7ec4de28783fd60e7c4", null ],
       [ "make", "classgr_1_1fft_1_1fft__v.html#a978d0d499b03c753c6f2c781c93e07f8", null ],
       [ "nthreads", "classgr_1_1fft_1_1fft__v.html#afeec441a9c43068d8c153016623e0bf1", null ],
