@@ -28,11 +28,6 @@ var NAVTREE =
     [ "Build Instructions and Information", "build_guide.html", null ],
     [ "Components", "page_components.html", "page_components" ],
     [ "License", "License.html", null ],
-    [ "Release Process Documentation", "page_releasing.html", [
-      [ "Preparation", "page_releasing.html#Preparation", null ],
-      [ "Tagging", "page_releasing.html#Release", null ],
-      [ "Of Archives", "page_releasing.html#Creation", null ]
-    ] ],
     [ "Topics", "topics.html", "topics" ],
     [ "Namespaces", "namespaces.html", [
       [ "Namespace List", "namespaces.html", "namespaces_dup" ],
@@ -104,59 +99,59 @@ var NAVTREEINDEX =
 "classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
 "classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
 "classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
-"classgr_1_1fec_1_1tpc__decoder.html#a91ed2ddf6aa73eb271d6e8231f7cb815",
-"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7c54ab3a48e8db3f8717a135be040db0",
+"classgr_1_1fec_1_1tpc__decoder.html#ac71a3fe1b3074d0392bbf0ae025cd713",
+"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7f6703c0ad752e773fff3aa90a867656",
 "classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
-"classgr_1_1filter_1_1single__pole__iir_3_01gr__complex_00_01i__type_00_01double_01_4.html",
+"classgr_1_1filter_1_1single__pole__iir_3_01gr__complex_00_01i__type_00_01double_01_4.html#a16a18c30612337692adc76769323d18e",
 "classgr_1_1iio_1_1device__source.html#adbbbd5fee5d4b2b2d00d0637301b88b7",
-"classgr_1_1msg__endpoint.html",
-"classgr_1_1qtgui_1_1ber__sink__b.html#ab6781079e44762c083009d967b27d797",
-"classgr_1_1qtgui_1_1freq__sink__c.html",
-"classgr_1_1qtgui_1_1histogram__sink__f.html#af9c42348178bb37d9d2716b77fa431ce",
-"classgr_1_1qtgui_1_1time__raster__sink__f.html#aa6b740ee6f4b605d423d542a5f51cb53",
-"classgr_1_1qtgui_1_1vector__sink__f.html#ab4acfe471289cea3d564594a59926e63",
-"classgr_1_1soapy_1_1block.html#a460c4a105d445fffe41e5d46a5eb913e",
-"classgr_1_1trellis_1_1fsm.html#ada8ac748ba79726207672df609f59d8b",
-"classgr_1_1uhd_1_1rfnoc__graph.html#a49365b0f1647db3adca9f3e8c2a63741",
-"classgr_1_1vocoder_1_1codec2.html#a4fb8331472faad41468ffdd68654e6f1a9ae88a1fbedbe773a14f0e90aaeb4092",
+"classgr_1_1msg__endpoint.html#a14bc4ad779b24c77c975b0f6c1b6649b",
+"classgr_1_1qtgui_1_1ber__sink__b.html#abbc064f162da722fe8663090fc7b9987",
+"classgr_1_1qtgui_1_1freq__sink__c.html#a0187a0131152e4d60e71659079c44f51",
+"classgr_1_1qtgui_1_1histogram__sink__f.html#afc05c848d11e435817f4100575362359",
+"classgr_1_1qtgui_1_1time__raster__sink__f.html#aa6baf71669fba0c9cbe310d789ea101f",
+"classgr_1_1qtgui_1_1vector__sink__f.html#abf103c04cd69da087714cb88c099d971",
+"classgr_1_1soapy_1_1block.html#a4cfc22e114a2006a293577a82d3c3dbc",
+"classgr_1_1trellis_1_1fsm.html#ae8cdb8948e2f148f18c7612d419b996d",
+"classgr_1_1uhd_1_1rfnoc__graph.html#a55f922bbeae810da681b5db9c72624d0",
+"classgr_1_1vocoder_1_1codec2.html#a4fb8331472faad41468ffdd68654e6f1aa299e9caf16a658972dccf581e3979a3",
 "classpmt_1_1pmt__base.html#a97bac3d60aa2f86fece6565f34fc4648",
-"classrpcserver__base.html#ad393fa1b463721770fcb170d2bb0b2db",
-"const__sink__c__pydoc__template_8h.html#adfffa9b9a797c17acd4451d9d394b4b2",
-"correctiq__man__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
-"ctrlport__probe2__s__pydoc__template_8h.html#a0e6b224359d8835ed8f00dc37268648c",
-"dir_163b61ceea2e02982ffc042218391854.html",
-"divide_8h_source.html",
-"dvbt__convolutional__deinterleaver__pydoc__template_8h.html#a4db011872acbc55eddcb60080f525de1",
-"eye__sink__f__pydoc__template_8h.html#a8485b5d8ebb13d760584b46778a31bca",
-"filterbank__pydoc__template_8h_source.html",
-"fmdet__cf__pydoc__template_8h_source.html",
-"functions_type_s.html",
-"globals_e.html",
-"gsm__fr__decode__ps_8h_source.html",
-"host__buffer__copy__pydoc__template_8h.html#adf4a6cf5f48f264b1c280f0c3d8e89e9",
-"ldpc__encoder__pydoc__template_8h.html#a06627acd79858c9dd873d87f2d4f7023",
-"message__pydoc__template_8h.html#a90599fa0a366fa0a9001c488d852d61a",
-"multiply__by__tag__value__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
-"namespacegr_1_1blocks.html#a92545f9390e438079b540545ce228944",
-"namespacegr_1_1dtv.html#a6756f8e55d0cb81f6f1d5a0ba7807bc1a6b42dfeedde75c99f8786fbec208a2aa",
-"namespacegr_1_1soapy.html",
-"namespacepmt.html#a0f26f38e24c533a8476dfb993a2bc7a7",
-"nlog10__ff_8h.html",
-"packet__headergenerator__bb__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
-"peak__detector2__fb__pydoc__template_8h.html#a40fd5e294ba7058a0f40d2da5f05e90a",
-"pfb__synthesizer__ccf__pydoc__template_8h.html#a4ffc7528d08939b3c6652c578965bad5",
-"pmt__pydoc__template_8h.html#a6a96b09b7b856ac58f4e025ab60e3d46",
-"polar__decoder__common__pydoc__template_8h.html#a5d92c4c5d930831a74fd9dc089b0464e",
-"pull__source__pydoc__template_8h.html#a18777fdfaea4ef8b4aec73efbfa55949",
-"repetition__encoder__pydoc__template_8h_source.html",
-"rotator__pydoc__template_8h.html#a94ca7787156825af12d59fac07c88732",
-"single__pole__iir__pydoc__template_8h_source.html",
-"streams__to__stream__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
-"structrpcpmtconverter_1_1to__pmt__s64vect__f.html#aa841e518fed84ce97e9c3d98fd886fd3",
-"tags__strobe__pydoc__template_8h.html",
-"time__sink__f__pydoc__template_8h.html#a66b112b842f2897887fa21773cf67c80",
-"usrp__block__pydoc__template_8h.html#a4914886d0686d7ffeaf3a53ab944298b",
-"waterfall__sink__c__pydoc__template_8h.html#a6941cae5cef7d4ddaae997c28dfa08db"
+"classrpcserver__base.html#ad65d23a4b1e9bfec36bdb3a17df14d22",
+"const__sink__c__pydoc__template_8h.html#af2e36ce06d20fb33fa8bd7c80802cd04",
+"correctiq__man__pydoc__template_8h.html#ae25263aaa55042014de05a0b68435b61",
+"ctrlport__probe2__s__pydoc__template_8h.html#a9b915a0b82ab1a83be3ec436cca16443",
+"dir_1a92d512b86599fa15333408b8ecf939.html",
+"docs_2doxygen_2pydoc__macros_8h.html",
+"dvbt__convolutional__deinterleaver__pydoc__template_8h_source.html",
+"eye__sink__f__pydoc__template_8h.html#a9196628537ada4d5673b0a656f776c1c",
+"filterbank__vcvcf__pydoc__template_8h.html#a01d18b2dfaec197f0f2122f0273ad40f",
+"form__menus__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
+"functions_vars.html",
+"globals_func.html",
+"gsm__fr__decode__ps__pydoc__template_8h.html#a976d0abafd2c1ae144e59151825566b1",
+"iir__filter_8h.html",
+"ldpc__encoder__pydoc__template_8h.html#aabd1056e1a2ba4670a005676293fec53",
+"message__pydoc__template_8h.html#af468f0cacf017e8d2aa23cdc97822957",
+"multiply__by__tag__value__cc__pydoc__template_8h_source.html",
+"namespacegr_1_1blocks.html#a97dc6283d9b3634237d2eadf8acaf704",
+"namespacegr_1_1dtv.html#a6a7633d61ed04d9f2d4629c46553300aa241b8f551be51e0278ac4feedc97bb50",
+"namespacegr_1_1soapy.html#a94171c3c45d214803f0644d14c4bf876",
+"namespacepmt.html#a116faa64b5e54219c9d14bef2fcc9c02",
+"nlog10__ff__pydoc__template_8h.html#a266da295ffe0111c1dd337210c0d2474",
+"packet__headergenerator__bb__pydoc__template_8h.html#ac3665b335f3d13be0234a8e87f3794bd",
+"peak__detector2__fb__pydoc__template_8h.html#ac28e256fa6638c67048f53d2e3873e9c",
+"phase__modulator__fc_8h.html",
+"pmt__pydoc__template_8h.html#a6fb3e30c80c4f1e77e804713274ad7fb",
+"polar__decoder__sc__list_8h.html",
+"puncture__bb_8h_source.html",
+"req__msg__source__pydoc__template_8h.html#acb043ca8957369ccda640cac31ab1383",
+"rpccallbackregister__base_8h.html#a083912edd1265872708667efecd2444b",
+"sink__c__pydoc__template_8h.html#a595325a6fe88a242be42d41547081db1",
+"streams__to__vector__pydoc__template_8h.html#ad5b4e98ced443a10bcb7b27b42164527",
+"structrpcpmtconverter_1_1to__pmt__short__f.html#a0a4b1d894a669f5ca835200846e4936e",
+"tags__strobe__pydoc__template_8h.html#a92dbdd45c3850b4e9ac26c914b8e498e",
+"time__sink__f__pydoc__template_8h.html#a98a283f94ba6dba67cca10238d5ff084",
+"usrp__block__pydoc__template_8h.html#a5cb607392f4ffd3b0e7e3984aa84c6b3",
+"waterfall__sink__c__pydoc__template_8h.html#a8dbc5d726def314ead64bbc0f4848c6e"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
