@@ -1,6 +1,6 @@
 var pdu__to__stream_8h =
 [
-    [ "gr::pdu::pdu_to_stream< T >", "classgr_1_1pdu_1_1pdu__to__stream.html", "classgr_1_1pdu_1_1pdu__to__stream" ],
+    [ "gr::pdu::pdu_to_stream&lt; T &gt;", "classgr_1_1pdu_1_1pdu__to__stream.html", "classgr_1_1pdu_1_1pdu__to__stream" ],
     [ "gr::pdu::pdu_to_stream_b", "namespacegr_1_1pdu.html#af4155fd42870cbe71e8a1d5a76596a87", null ],
     [ "gr::pdu::pdu_to_stream_c", "namespacegr_1_1pdu.html#ad4abaeddc82e119de77f5339336d44ed", null ],
     [ "gr::pdu::pdu_to_stream_f", "namespacegr_1_1pdu.html#abf1da0a28e29eddde313abdd3d44559e", null ],
